@@ -73,7 +73,7 @@ struct _ECalBackendClass {
 	void (* get_ldap_attribute) (ECalBackend *backend, EDataCal *cal);
 	void (* get_static_capabilities) (ECalBackend *backend, EDataCal *cal);
 	
-	void (* open) (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists);
+	void (* open) (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists, const char *username, const char *password);
 	void (* remove) (ECalBackend *backend, EDataCal *cal);
 
 	/* Object related virtual methods */
@@ -127,7 +127,7 @@ void e_cal_backend_get_alarm_email_address (ECalBackend *backend, EDataCal *cal)
 void e_cal_backend_get_ldap_attribute (ECalBackend *backend, EDataCal *cal);
 void e_cal_backend_get_static_capabilities (ECalBackend *backend, EDataCal *cal);
 
-void e_cal_backend_open (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists);
+void e_cal_backend_open (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists, const char *username, const char *password);
 void e_cal_backend_remove (ECalBackend *backend, EDataCal *cal);
 
 void e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const char *calobj);
@@ -168,8 +168,8 @@ void e_cal_backend_notify_object_modified (ECalBackend *backend, const char *old
 void e_cal_backend_notify_object_removed  (ECalBackend *backend, const char *uid, const char *old_object);
 
 void e_cal_backend_notify_mode      (ECalBackend *backend,
-				   GNOME_Evolution_Calendar_CalListener_SetModeStatus status, 
-				   GNOME_Evolution_Calendar_CalMode mode);
+				     GNOME_Evolution_Calendar_CalListener_SetModeStatus status, 
+				     GNOME_Evolution_Calendar_CalMode mode);
 void e_cal_backend_notify_error     (ECalBackend *backend, const char *message);
 void e_cal_backend_ref_categories   (ECalBackend *backend, GSList *categories);
 void e_cal_backend_unref_categories (ECalBackend *backend, GSList *categories);
