@@ -3,7 +3,7 @@
   FILE: icaltime.c
   CREATOR: eric 02 June 2000
   
-  $Id: icaltime.c,v 1.32 2004/05/25 09:34:01 rodrigo Exp $
+  $Id: icaltime.c,v 1.32.8.1 2004/10/26 23:01:06 rodrigo Exp $
   $Locker:  $
     
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -334,7 +334,16 @@ void unset_tz(char *tzstr)
     if(tzstr!=0){
 	putenv(tzstr);
     } else {
-	putenv("TZ"); /* Delete from environment */
+	/* Delete from environment.  We prefer unsetenv(3) over putenv(3)
+	   because the former is POSIX and behaves consistently.  The later
+	   does not unset the variable in some systems (like NetBSD), leaving
+	   it with an empty value.  This causes problems later because further
+	   calls to time related functions in libc will treat times in UTC. */
+#ifdef HAVE_UNSETENV
+	unsetenv("TZ");
+#else
+	putenv("TZ");
+#endif
     } 
 
     /* Free any previous TZ environment string we have used. */
