@@ -64,6 +64,7 @@ e_gw_connection_parse_response_status (SoupSoapResponse *response)
 	switch (soup_soap_parameter_get_int_value (subparam)) {
 	case 0 : return E_GW_CONNECTION_STATUS_OK;
 	case 59905 : return E_GW_CONNECTION_STATUS_BAD_PARAMETER;
+	case 59914: return E_GW_CONNECTION_STATUS_ITEM_ALREADY_ACCEPTED;
 		/* FIXME: map all error codes */
 	}
 
@@ -130,11 +131,32 @@ e_gw_connection_dispose (GObject *object)
 {
 	EGwConnection *cnc = (EGwConnection *) object;
 	EGwConnectionPrivate *priv;
-
+	char *hash_key;
+	gpointer orig_key, orig_value;
+	
 	g_return_if_fail (E_IS_GW_CONNECTION (cnc));
 	
 	priv = cnc->priv;
 	printf ("gw connection dispose \n");
+	
+	/* removed the connection from the hash table */
+	if (loaded_connections != NULL) {
+		hash_key = g_strdup_printf ("%s:%s@%s",
+					    priv->username ? priv->username : "",
+					    priv->password ? priv->password : "",
+					    priv->uri);
+		if (g_hash_table_lookup_extended (loaded_connections, hash_key, &orig_key, &orig_value)) {
+			g_hash_table_remove (loaded_connections, hash_key);
+			if (g_hash_table_size (loaded_connections) == 0) {
+				g_hash_table_destroy (loaded_connections);
+				loaded_connections = NULL;
+			}
+
+			g_free (orig_key);
+		}
+		g_free (hash_key);
+	}
+	
 	if (priv) {
 		if (priv->session_id) {
 			logout (cnc);
@@ -184,8 +206,6 @@ e_gw_connection_dispose (GObject *object)
 static void
 e_gw_connection_finalize (GObject *object)
 {
-	char *hash_key;
-	gpointer orig_key, orig_value;
 	EGwConnection *cnc = (EGwConnection *) object;
 	EGwConnectionPrivate *priv;
 
@@ -197,24 +217,6 @@ e_gw_connection_finalize (GObject *object)
 	g_free (priv);
 	cnc->priv = NULL;
 
-	/* removed the connection from the hash table */
-	if (loaded_connections != NULL) {
-		hash_key = g_strdup_printf ("%s:%s@%s",
-					    priv->username ? priv->username : "",
-					    priv->password ? priv->password : "",
-					    priv->uri);
-		if (g_hash_table_lookup_extended (loaded_connections, hash_key, &orig_key, &orig_value)) {
-			g_hash_table_remove (loaded_connections, hash_key);
-			if (g_hash_table_size (loaded_connections) == 0) {
-				g_hash_table_destroy (loaded_connections);
-				loaded_connections = NULL;
-			}
-
-			g_free (orig_key);
-		}
-		g_free (hash_key);
-	}
-
 	if (parent_class->finalize)
 		(* parent_class->finalize) (object);
 }
@@ -327,7 +329,7 @@ e_gw_connection_new (const char *uri, const char *username, const char *password
 	cnc->priv->session_id = g_strdup (soup_soap_parameter_get_string_value (param));
 
 	/* retrieve user information */
-	param = soup_soap_response_get_first_parameter_by_name (response, "UserInfo");
+	param = soup_soap_response_get_first_parameter_by_name (response, "userinfo");
 	if (param) {
 		SoupSoapParameter *subparam;
 		const char *param_value;
